==> tine20-tasks_2016.11.24.tar.bz2: Tasks/js/Tasks-lang-pt_BR-debug.js <==
/********************** tine translations of Tasks**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Tasks'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2015-12-03 17:17+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "%s's personal tasks"
: "%s's tarefas pessoais"

, "manage shared task lists"
: "gerenciar listas de tarefas compartilhadas"

, "Create new shared tasks lists"
: "Criar novas listas de tarefas compartilhadas"

, "manage shared tasks favorites"
: "gerenciar tarefas favoritas compartilhadas"

, "Create or update shared tasks favorites"
: "Criar ou atualizar as tarefas favoritas compartilhadas"

, "Due"
: "Esperado"

, "Organizer"
: "Organizador"

, "Description"
: "Descrição"

, "Priority"
: "Prioridade"

, "Status, Status"
: [
  "Situação"
 ,"Situação"

]
, "Percent"
: "Percentual"

, "Lead"
: "Líder"

, "Telephone"
: "Telefone"

, "Email"
: "Email"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Você tem que fornecer uma data de vencimento, porque um alarme está programado"

, "Summary"
: "Sumário"

, "Due date"
: "Data de vencimento"

, "Add Responsible ..."
: "Adicionar Responsável ..."

, "Notes"
: "Anotações"

, "Enter description..."
: "Informe a descrição..."

, "Percentage"
: "Percentagem"

, "Completed"
: "Completado"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Você quer realmente apagar a tarefa selecionada?"
 ,"Você quer realmente apagar as tarefas selecionadas?"

]
, "Tags"
: "Identificação"

, "Lead name"
: ""

, "Add a task..."
: "Adicionar tarefa..."

, "Due Date"
: "Data de Vencimento"

, "Creation Time"
: "Hora de Criação"

, "Responsible"
: "Responsável"

, "New Task"
: "Nova Tarefa"

, "Task, Tasks"
: [
  "Tarefa"
 ,"Tarefas"

]
, "Tasks"
: "Tarefas"

, "to do list, to do lists"
: [
  "Lista dos A Fazer"
 ,"Listas dos A Fazer"

]
, "to do lists"
: "Lista dos A Fazer"

, "Quick Search"
: "Busca Rápida"

, "Last Modified Time"
: "Hora da Última modificação"

, "Last Modified By"
: "Modificado por"

, "Created By"
: "Criado por"

, "Notification for Task "
: "Notificação para a Tarefa "

, "All my tasks"
: "Todas as minhas tarefas"

, "Default Favorite"
: "Favorito Básico"

, "The default favorite which is loaded on Tasks startup"
: "O favorito básico que foi carregado em Tarefas no início"

, "Default Task List"
: "Lista de Tarefas Básica"

, "The default task list to create new tasks in."
: "Lista de tarefa básica para criar novas tarefas em."

, "Tasks status available"
: "Situação das Tarefas disponível"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Possível situação de tarefas.  Observe que o status do participante adicional pode impactar em outras Tarefas do sistema na exportação ou sincronização."

, "No response"
: "Sem resposta"

, "Cancelled"
: "Cancelado"

, "In process"
: "Em processo"

, "Task priorities available"
: "Prioridades de Tarefas disponíveis"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Possível prioridades para tarefas.  Favor observar que prioridades adicionais podem impactar em outras Tarefas do sistema na exportação ou sincronização."

, "low"
: "baixo"

, "normal"
: "normal"

, "high"
: "alto"

, "urgent"
: "urgente"

, "All tasks of my taskslists"
: "Todas as tarefas das minhas listas de tarefas"

, "My open tasks"
: "Minhas tarefas abertas"

, "My open tasks this week"
: "Minhas tarefas abertas esta semana"

, "All tasks for me"
: "Todas as minhas tarefas"

, "All tasks that I am responsible for"
: "Todas as tarefas que eu sou responsaǘel"

, "Last modified by me"
: "Última modificada por mim"

, "All tasks that I have last modified"
: "Todas as tarefas que eu modifiquei ultimamente"

, "Tasks without responsible"
: "Tarefas sem responsável"

, "Status"
: "Situação"

, "Do you really want to delete the selected task?"
: "Você quer realmente apagar a tarefa selecionada?"

, "Task"
: "Tarefa"

, "to do list"
: "Lista dos A Fazer"

}));

==> tine20-tasks_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Tarefa"
 ,"Tarefas"

]
, "Percent"
: "Percentual"

, "Completed"
: "Completado"

, "Due"
: "Esperado"

, "Class"
: ""

, "Description"
: "Descrição"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organizador"

, "Priority"
: "Prioridade"

, "Status, Status"
: [
  "Situação"
 ,"Situação"

]
, "Lead"
: "Líder"

, "Telephone"
: "Telefone"

, "Email"
: "Email"

, "Add New Task"
: "Adicionar Nova Tarefa"

, "You have to supply a due date, because an alarm ist set!"
: "Você tem que fornecer uma data de vencimento, porque um alarme está programado"

, "Summary"
: "Sumário"

, "Due date"
: "Data de vencimento"

, "Add Responsible ..."
: "Adicionar Responsável ..."

, "Notes"
: "Anotações"

, "Enter description..."
: "Informe a descrição..."

, "Percentage"
: "Percentagem"

, "Tasks"
: "Tarefas"

, "to do list, to do lists"
: [
  "Lista dos A Fazer"
 ,"Listas dos A Fazer"

]
, "to do lists"
: "Lista dos A Fazer"

, "Quick Search"
: "Busca Rápida"

, "Due Date"
: "Data de Vencimento"

, "Responsible"
: "Responsável"

, "Last Modified Time"
: "Hora da Última modificação"

, "Last Modified By"
: "Modificado por"

, "Creation Time"
: "Hora de Criação"

, "Created By"
: "Criado por"

, "New Task"
: "Nova Tarefa"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Você quer realmente apagar a tarefa selecionada?"
 ,"Você quer realmente apagar as tarefas selecionadas?"

]
, "Attachments"
: ""

, "Tags"
: "Identificação"

, "Lead name"
: "Nome principal"

, "Add a task..."
: "Adicionar tarefa..."

, "All my tasks"
: "Todas as minhas tarefas"

, "Default Favorite"
: "Favorito Básico"

, "The default favorite which is loaded on Tasks startup"
: "O favorito básico que foi carregado em Tarefas no início"

, "Default Task List"
: "Lista de Tarefas Básica"

, "The default task list to create new tasks in."
: "Lista de tarefa básica para criar novas tarefas em."

, "Tasks status available"
: "Situação das Tarefas disponível"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Possível situação de tarefas.  Observe que o status do participante adicional pode impactar em outras Tarefas do sistema na exportação ou sincronização."

, "No response"
: "Sem resposta"

, "Cancelled"
: "Cancelado"

, "In process"
: "Em processo"

, "Task priorities available"
: "Prioridades de Tarefas disponíveis"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Possível prioridades para tarefas.  Favor observar que prioridades adicionais podem impactar em outras Tarefas do sistema na exportação ou sincronização."

, "low"
: "baixo"

, "normal"
: "normal"

, "high"
: "alto"

, "urgent"
: "urgente"

, "manage shared task lists"
: "gerenciar listas de tarefas compartilhadas"

, "Create new shared tasks lists"
: "Criar novas listas de tarefas compartilhadas"

, "manage shared tasks favorites"
: "gerenciar tarefas favoritas compartilhadas"

, "Create or update shared tasks favorites"
: "Criar ou atualizar as tarefas favoritas compartilhadas"

, "%s's personal tasks"
: "%s's tarefas pessoais"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Todas as tarefas das minhas listas de tarefas"

, "My open tasks"
: "Minhas tarefas abertas"

, "My open tasks this week"
: "Minhas tarefas abertas esta semana"

, "All tasks for me"
: "Todas as minhas tarefas"

, "All tasks that I am responsible for"
: "Todas as tarefas que eu sou responsaǘel"

, "Last modified by me"
: "Última modificada por mim"

, "All tasks that I have last modified"
: "Todas as tarefas que eu modifiquei ultimamente"

, "Tasks without responsible"
: "Tarefas sem responsável"

, "GENDER_Task"
: ""

, "Task"
: "Tarefa"

, "Status"
: "Situação"

, "to do list"
: "Lista dos A Fazer"

, "Do you really want to delete the selected task?"
: "Você quer realmente apagar a tarefa selecionada?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
